﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#include <aws/amp/model/ListScrapersResult.h>
#include <aws/core/utils/json/JsonSerializer.h>
#include <aws/core/AmazonWebServiceResult.h>
#include <aws/core/utils/StringUtils.h>
#include <aws/core/utils/UnreferencedParam.h>
#include <aws/core/utils/memory/stl/AWSStringStream.h>

#include <utility>

using namespace Aws::PrometheusService::Model;
using namespace Aws::Utils::Json;
using namespace Aws::Utils;
using namespace Aws;

ListScrapersResult::ListScrapersResult()
{
}

ListScrapersResult::ListScrapersResult(const Aws::AmazonWebServiceResult<JsonValue>& result)
{
  *this = result;
}

ListScrapersResult& ListScrapersResult::operator =(const Aws::AmazonWebServiceResult<JsonValue>& result)
{
  JsonView jsonValue = result.GetPayload().View();
  if(jsonValue.ValueExists("nextToken"))
  {
    m_nextToken = jsonValue.GetString("nextToken");

  }

  if(jsonValue.ValueExists("scrapers"))
  {
    Aws::Utils::Array<JsonView> scrapersJsonList = jsonValue.GetArray("scrapers");
    for(unsigned scrapersIndex = 0; scrapersIndex < scrapersJsonList.GetLength(); ++scrapersIndex)
    {
      m_scrapers.push_back(scrapersJsonList[scrapersIndex].AsObject());
    }
  }


  const auto& headers = result.GetHeaderValueCollection();
  const auto& requestIdIter = headers.find("x-amzn-requestid");
  if(requestIdIter != headers.end())
  {
    m_requestId = requestIdIter->second;
  }


  return *this;
}
